# -*- coding: utf-8 -*-

from django.utils.translation import ugettext as _
from django.contrib import admin
from django.conf import settings
from django.conf.urls import patterns, url

from jmb.core.admin.options import ExtendibleModelAdmin
from jmb.address.admin import AddressCoordinatesAdmin
from acomea.distributor.models import Distributor, Branch
from acomea.distributor.admin_views import BranchImportView

from image_cropping import ImageCroppingMixin


class DistributorAdmin(ImageCroppingMixin, ExtendibleModelAdmin):
    list_display = (
        'get_admin_marker', 'get_status_icon', 'name', 'get_edit_icon', 'get_delete_icon',
    )
    fieldsets = (
        (_('logs admin'), {
            'fields': (
                'creator', 'date_create',
                'last_modifier', 'date_last_modify',
            ),
            'classes': ('collapse',)
        }),
        (None, {
            'fields': ('name', 'marker', 'cropping',),
        }),
    )
    search_fields = ('name',)
    list_filter = ('status',)


class BranchAdmin(ExtendibleModelAdmin, AddressCoordinatesAdmin):
    list_display = (
        'get_status_icon',
        'distributor', 'city', 'address', 'cap', 'province', 'email', 'phone', 'lat', 'lng',
        'get_edit_icon', 'get_delete_icon',
    )
    fieldsets = (
        (_('logs admin'), {
            'fields': (
                'creator', 'date_create',
                'last_modifier', 'date_last_modify',
            ),
            'classes': ('collapse',)
        }),
        (None, {
            'fields': ('distributor', 'city', 'address', 'cap', 'name', 'province', 'email', 'phone',),
        }),
        (_('coordinates'), {
            'fields': ('lat', 'lng', 'google_map'),
        }),
    )
    search_fields = ('city', 'address', 'cap', 'province', 'email', 'phone')
    list_filter = ('status', 'distributor',)

    def get_urls(self):
        urls = super(BranchAdmin, self).get_urls()
        my_urls = patterns(
            '',
            url(
                r'^import/$',
                self.admin_site.admin_view(BranchImportView.as_view()),
                name='distributor_branch_import'
            ),
        )
        return my_urls + urls


admin.site.register(Distributor, DistributorAdmin)
admin.site.register(Branch, BranchAdmin)