# -*- coding: utf-8 -*-

from django import forms
from django.utils.translation import ugettext as _
from django_select2.fields import ModelSelect2MultipleField

from acomea.distributor.models import Distributor


class BranchFinderForm(forms.Form):
    distributors = ModelSelect2MultipleField(
        label=_('Distributors'), queryset=Distributor.objects, required=False,
    )

    def __init__(self, *args, **kwargs):
        self.plugin_instance = kwargs.pop('plugin_instance')
        super(BranchFinderForm, self).__init__(*args, **kwargs)
        self.fields['distributors'].widget.attrs.update({'placeholder': _('Select desired distributors')})
        if self.plugin_instance.related_distributors.count():
            enabled_distributors = self.plugin_instance.related_distributors.all().values_list('distributor', flat=True)
            self.fields['distributors'].queryset = Distributor.objects.filter(id__in=enabled_distributors)
