# -*- coding: utf-8 -*-

from cms.models.pluginmodel import CMSPlugin
from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.conf import settings

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel
from acomea.distributor.models import Distributor


class BranchesFinderSettings(CMSPlugin, DateModel, UserModel, StatusModel):
    name = models.CharField(
        max_length=255,
        verbose_name=_('name'),
    )
    template_name = models.CharField(
        max_length=255,
        choices=settings.ACOMEA_DISTRIBUTOR_CMSPLUGIN_BRANCHES_FINDER_TEMPLATES,
        default='bootstrap3/distributor/cms_plugins/branches_finder.html'
    )

    class Meta:
        app_label = "distributor"
        verbose_name = _('branches finder')
        verbose_name_plural = _('branches finders')

    def __unicode__(self):
        status_display_map = {0: "off", 1: "on"}
        return u'{} - {}'.format(status_display_map[self.status], self.name)


class BranchesFinderSettingsDistributor(DateModel, UserModel):
    branches_finder_setting = models.ForeignKey(
        BranchesFinderSettings,
        verbose_name=_("Branches finder setting"),
        related_name='related_distributors',
    )
    distributor = models.ForeignKey(
        Distributor,
        verbose_name=_('Distributor'),
        related_name='cmsplugin_distributor_branches_finder_settings',
    )

    class Meta:
        app_label = "distributor"
        verbose_name = _("Branches finder distributor")
        verbose_name_plural = _("Branches finder distributors")
        ordering = ('branches_finder_setting',)

    def __unicode__(self):
        return u"{}".format(self.branches_finder_setting.template_name)
