# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import ugettext as _
from django.core.urlresolvers import reverse
from django.conf import settings
from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from acomea.distributor.cms import models as cms_models
from acomea.distributor.cms.forms import BranchFinderForm


class BranchesFinderSettingsDistributorInline(admin.TabularInline):
    model = cms_models.BranchesFinderSettingsDistributor
    extra = 0
    fields = ('distributor',)


class BranchesFinderPlugin(CMSPluginBase):
    model = cms_models.BranchesFinderSettings
    module = _('Distributor')
    name = _("Branches finder")
    admin_preview = False
    inlines = (BranchesFinderSettingsDistributorInline,)
    fieldsets = (
        (_('general info'), {'fields': (
            'name', 'template_name',
        )}),
    )
    render_template = "bootstrap3/distributor/cms_plugins/empty.html"
    admin_preview = False

    def render(self, context, instance, placeholder):
        self.render_template = instance.template_name
        form = BranchFinderForm(plugin_instance=instance)
        url = reverse("distributor:branches")
        distributor = instance.related_distributors.all()[0].distributor.id \
            if instance.related_distributors.all().count() == 1 else 0
        context.update({
            'instance': instance,
            'form': form,
            'google_map_key': settings.ADDRESS_GOOGLE_GEOCODING_KEY,
            'url': url,
            'distributor': distributor,
        })
        return context

plugin_pool.register_plugin(BranchesFinderPlugin)